@@ -376,6 +376,8 @@ int evaltag(char *wholetag,int linenumber,int is_anchor){
 	 * We must therefore alwasy check for anchors (name= and href=)
 	 * and then for src...
 	 * <a name="Top"><img src="image.jpg">Image</a> 
+	 * A tag like <a name="xxxx" href="...."> .... </a> is also
+	 * possible.
 	 * It is not possible to have background together with an anchor.
 	 * It is also not possible to have nested anchors
 	 */
@@ -384,10 +386,6 @@ int evaltag(char *wholetag,int linenumber,int is_anchor){
 		/* 0 no match, 1 href, 2 src, 3 background */
 		typeoflink=1;
 		print_result(linenumber);
-	}else if (matchpat(wholetag," name *= *",&pathstartptr)){
-		copy_file_path(pathstartptr);
-		add_to_fifo_unless_there(2,get_named_anchor_path(pathstr),"");
-		/* no print_result here */
 	}else if (matchpat(wholetag," background *= *",&pathstartptr)){
 		copy_file_path(pathstartptr);
 		typeoflink=3;
@@ -399,6 +397,11 @@ int evaltag(char *wholetag,int linenumber,int is_anchor){
 		typeoflink=2;
 		print_result(linenumber);
 	}
+	if (matchpat(wholetag," name *= *",&pathstartptr)){
+		copy_file_path(pathstartptr);
+		add_to_fifo_unless_there(2,get_named_anchor_path(pathstr),"");
+		/* no print_result here */
+	}
 	return(0);
 }
 /* check if this is a named anchor , argument to findtag*/
